/*
 * This file is part of OpenOrienteering.
 * 
 * This file is not compiled.
 * These string are used for packaging and desktop integration.
 */

#define QT_TRANSLATE_NOOP(a,b)

QT_TRANSLATE_NOOP("OpenOrienteering", "Orienteering map");
QT_TRANSLATE_NOOP("OpenOrienteering", "Software for drawing orienteering maps");

//: For the moment, we use this existing translation instead of the previous one.
QT_TRANSLATE_NOOP("OpenOrienteering::AboutDialog", "A free software for drawing orienteering maps");
